Hello community,

here is the log from the commit of package kfloppy for openSUSE:Factory checked 
in at 2016-01-10 13:05:08
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Comparing /work/SRC/openSUSE:Factory/kfloppy (Old)
 and      /work/SRC/openSUSE:Factory/.kfloppy.new (New)
++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Package is "kfloppy"

Changes:
--------
--- /work/SRC/openSUSE:Factory/kfloppy/kfloppy.changes  2015-11-15 
12:34:49.000000000 +0100
+++ /work/SRC/openSUSE:Factory/.kfloppy.new/kfloppy.changes     2016-01-10 
13:05:12.000000000 +0100
@@ -1,0 +2,9 @@
+Sun Dec 13 13:18:15 UTC 2015 - [email protected]
+
+- Update to KDE Applications 15.12.0
+   * KDE Applications 15.12.0 
+   * https://www.kde.org/announcements/announce-applications-15.12.0.php
+   * boo#958887
+
+
+-------------------------------------------------------------------

Old:
----
  kfloppy-15.08.3.tar.xz

New:
----
  kfloppy-15.12.0.tar.xz

++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++

Other differences:
------------------
++++++ kfloppy.spec ++++++
--- /var/tmp/diff_new_pack.Vd8Yhc/_old  2016-01-10 13:05:13.000000000 +0100
+++ /var/tmp/diff_new_pack.Vd8Yhc/_new  2016-01-10 13:05:13.000000000 +0100
@@ -17,7 +17,7 @@
 
 
 Name:           kfloppy
-Version:        15.08.3
+Version:        15.12.0
 Release:        0
 Summary:        Floppy Formatter
 License:        GPL-2.0+

++++++ kfloppy-15.08.3.tar.xz -> kfloppy-15.12.0.tar.xz ++++++
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kfloppy-15.08.3/CMakeLists.txt 
new/kfloppy-15.12.0/CMakeLists.txt
--- old/kfloppy-15.08.3/CMakeLists.txt  2014-07-25 07:44:00.000000000 +0200
+++ new/kfloppy-15.12.0/CMakeLists.txt  2015-12-09 15:48:01.000000000 +0100
@@ -24,7 +24,7 @@
 
 kde4_add_executable(kfloppy ${kfloppy_SRCS})
 
-target_link_libraries(kfloppy ${KDE4_KDE3SUPPORT_LIBS} ${KDE4_KIO_LIBS} )
+target_link_libraries(kfloppy ${KDE4_KIO_LIBS} )
 
 install(TARGETS kfloppy  ${INSTALL_TARGETS_DEFAULT_ARGS} )
 
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kfloppy-15.08.3/KFloppy.desktop 
new/kfloppy-15.12.0/KFloppy.desktop
--- old/kfloppy-15.08.3/KFloppy.desktop 2014-07-25 07:44:00.000000000 +0200
+++ new/kfloppy-15.12.0/KFloppy.desktop 2015-12-09 15:48:01.000000000 +0100
@@ -147,7 +147,6 @@
 Name[x-test]=xxKFloppyxx
 Name[zh_CN]=KFloppy
 Name[zh_TW]=KDE 軟碟
-MimeType=
 X-DocPath=kfloppy/index.html
 Exec=kfloppy -caption %c
 Icon=kfloppy
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kfloppy-15.08.3/format.cpp 
new/kfloppy-15.12.0/format.cpp
--- old/kfloppy-15.08.3/format.cpp      2014-07-25 07:44:00.000000000 +0200
+++ new/kfloppy-15.12.0/format.cpp      2015-12-09 15:48:01.000000000 +0100
@@ -29,7 +29,7 @@
 #include <QRegExp>
 
 #include <klocale.h>
-#include <k3process.h>
+#include <KProcess>
 #include <kdebug.h>
 #include <kstandarddirs.h>
 
@@ -321,19 +321,23 @@
        return true;
 }
 
-void FloppyAction::processDone(K3Process *p)
+void FloppyAction::readStdOut()
 {
-       DEBUGSETUP;
+       processStdOut( theProcess->readAllStandardOutput() );
+}
 
-       if (p!=theProcess)
-       {
-               DEBUGS("  Strange process exited.");
-               return;
-       }
+void FloppyAction::readStdErr()
+{
+       processStdOut( theProcess->readAllStandardError() );
+}
 
-       if (p->normalExit())
+void FloppyAction::processDone(int exitCode, QProcess::ExitStatus exitStatus)
+{
+       DEBUGSETUP;
+
+       if (exitStatus == QProcess::NormalExit)
        {
-               if (p->exitStatus() == 0)
+               if (exitCode == 0)
                {
                        emit status(QString::null,100); 
//krazy:exclude=nullstrassign for old broken gcc
                        emit done(this,true);
@@ -351,32 +355,31 @@
        }
 }
 
-void FloppyAction::processStdOut(K3Process *, char *b, int l)
+void FloppyAction::processStdOut(const QString &s)
 {
-       Q_UNUSED(b);
-       Q_UNUSED(l);
-       kDebug(KFAREA) << "stdout:" << QString::fromLatin1(b,l) ;
+       kDebug(KFAREA) << "stdout:" << s;
 }
 
-void FloppyAction::processStdErr(K3Process *p, char *b, int l)
+void FloppyAction::processStdErr(const QString &s)
 {
-       processStdOut(p,b,l);
+       processStdOut(s);
 }
 
 bool FloppyAction::startProcess()
 {
        DEBUGSETUP;
 
-       connect(theProcess,SIGNAL(processExited(K3Process*)),
-               this,SLOT(processDone(K3Process*)));
-       connect(theProcess,SIGNAL(receivedStdout(K3Process*,char*,int)),
-               this,SLOT(processStdOut(K3Process*,char*,int)));
-       connect(theProcess,SIGNAL(receivedStderr(K3Process*,char*,int)),
-               this,SLOT(processStdErr(K3Process*,char*,int)));
-
-        theProcess->setEnvironment( QLatin1String( "LC_ALL" ), QLatin1String( 
"C" ) ); // We need the untranslated output of the tool
-       return theProcess->start(K3Process::NotifyOnExit,
-               K3Process::AllOutput);
+       connect(theProcess, SIGNAL(finished(int, QProcess::ExitStatus)),
+               this, SLOT(processDone(int, QProcess::ExitStatus)));
+       connect(theProcess, SIGNAL(readyReadStandardOutput()),
+               this, SLOT(readStdOut()));
+       connect(theProcess, SIGNAL(readyReadStandardError()),
+               this, SLOT(readStdErr()));
+
+       theProcess->setEnv( QLatin1String( "LC_ALL" ), QLatin1String( "C" ) ); 
// We need the untranslated output of the tool
+       theProcess->setOutputChannelMode(KProcess::SeparateChannels);
+       theProcess->start();
+       return (theProcess->exitStatus() == QProcess::NormalExit);
 }
 
 
@@ -422,7 +425,7 @@
        }
 
        delete theProcess;
-       theProcess = new K3Process;
+       theProcess = new KProcess;
 
        formatTrackCount=0;
 
@@ -461,10 +464,9 @@
 // need, since the messages can be standardized across OSsen.
 //
 //
-void FDFormat::processStdOut(K3Process *, char *b, int l)
+void FDFormat::processStdOut(const QString &s)
 {
        DEBUGSETUP;
-       QString s;
 
 #ifdef ANY_BSD
        if (b[0]=='F')
@@ -479,7 +481,6 @@
        }
        else
        {
-               s = QString::fromLatin1(b,l);
                if (s.contains(QLatin1String( "ioctl(FD_FORM)" )))
                {
                     emit status (i18n(
@@ -496,7 +497,6 @@
                DEBUGS(s);
        }
 #elif defined(ANY_LINUX)
-       s = QString::fromLatin1(b,l);
        DEBUGS(s);
         QRegExp regexp( QLatin1String( "([0-9]+)" ) );
         if ( s.startsWith( QLatin1String( "bad data at cyl" ) ) || s.contains( 
QLatin1String( "Problem reading cylinder" ) ) )
@@ -583,7 +583,7 @@
     }
 
     delete theProcess;
-    theProcess = new K3Process;
+    theProcess = new KProcess;
 
     *theProcess << m_ddName ;
 
@@ -598,15 +598,12 @@
 
 }
 
-void DDZeroOut::processDone(K3Process *p)
+void DDZeroOut::processDone(int exitCode, QProcess::ExitStatus exitStatus)
 {
-    kDebug(KFAREA) << k_funcinfo ;
+    Q_UNUSED(exitCode);
+    Q_UNUSED(exitStatus);
 
-    if (p!=theProcess)
-    {
-            kDebug(KFAREA) << "Strange process exited." ;
-            return;
-    }
+    kDebug(KFAREA) << k_funcinfo ;
 
     /**
      * As we do not give a number of blocks to dd(1), it will stop
@@ -680,7 +677,7 @@
        }
 
        delete theProcess;
-       K3Process *p = theProcess = new K3Process;
+       KProcess *p = theProcess = new KProcess;
 
        *p << newfs_fat;
 #ifdef ANY_BSD
@@ -710,14 +707,13 @@
        }
 }
 
-void FATFilesystem::processStdOut(K3Process *, char *b, int l)
+void FATFilesystem::processStdOut(const QString &s)
 {
 #ifdef ANY_BSD
     // ### TODO: do some checks
 #elif defined(ANY_LINUX)
-    QString s ( QString::fromLatin1( b, l ) );
     kDebug(KFAREA) << s ;
-    if (s.contains(QLatin1String( "mounted file system" ))) // "/dev/fd0 
contains a mounted file system
+    if (s.contains(QLatin1String( "mounted" ))) // "/dev/fd0 contains a 
mounted filesystem"
     {
         emit status(i18n("Floppy is mounted.\nYou need to unmount the floppy 
first."),-1);
         return;
@@ -779,7 +775,7 @@
        }
 
        delete theProcess;
-       K3Process *p = theProcess = new K3Process;
+       KProcess *p = theProcess = new KProcess;
 
        *p << newfs;
 
@@ -857,7 +853,7 @@
        }
 
        delete theProcess;
-       K3Process *p = theProcess = new K3Process;
+       KProcess *p = theProcess = new KProcess;
 
        *p << newfs;
        *p << "-q";
@@ -873,12 +869,11 @@
        }
 }
 
-void Ext2Filesystem::processStdOut(K3Process *, char *b, int l)
+void Ext2Filesystem::processStdOut(const QString &s)
 {
 #ifdef ANY_BSD
     // ### TODO: do some checks
 #elif defined(ANY_LINUX)
-    QString s ( QString::fromLatin1( b, l ) );
     kDebug(KFAREA) << s ;
     if (s.contains(QLatin1String( "mounted" ))) // "/dev/fd0 is mounted; will 
not make a filesystem here!"
     {
@@ -951,7 +946,7 @@
        }
 
        delete theProcess;
-       K3Process *p = theProcess = new K3Process;
+       KProcess *p = theProcess = new KProcess;
 
        *p << newfs;
 
@@ -967,9 +962,8 @@
        }
 }
 
-void MinixFilesystem::processStdOut(K3Process *, char *b, int l)
+void MinixFilesystem::processStdOut(const QString &s)
 {
-    QString s ( QString::fromLatin1( b, l ) );
     kDebug(KFAREA) << s ;
     if (s.contains(QLatin1String( "mounted" ))) // "mkfs.minix: /dev/fd0 is 
mounted; will not make a filesystem here!"
     {
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kfloppy-15.08.3/main.cpp new/kfloppy-15.12.0/main.cpp
--- old/kfloppy-15.08.3/main.cpp        2014-07-25 07:44:00.000000000 +0200
+++ new/kfloppy-15.12.0/main.cpp        2015-12-09 15:48:01.000000000 +0100
@@ -37,7 +37,7 @@
 {
   KAboutData aboutData("kfloppy", 0,
        ki18n("KFloppy"),
-    "4.9 pre", ki18n(description), KAboutData::License_GPL,
+    "4.9", ki18n(description), KAboutData::License_GPL,
     ki18n("(c) 1997, Bernd Johannes Wuebben\n"
     "(c) 2001, Chris Howells\n"
     "(c) 2002, Adriaan de Groot\n"


Reply via email to
diff -urN '--exclude=CVS' '--exclude=.cvsignore' '--exclude=.svn' 
'--exclude=.svnignore' old/kfloppy-15.08.3/format.h new/kfloppy-15.12.0/format.h
--- old/kfloppy-15.08.3/format.h        2014-07-25 07:44:00.000000000 +0200
+++ new/kfloppy-15.12.0/format.h        2015-12-09 15:48:01.000000000 +0100
@@ -55,6 +55,7 @@
 
 #include "debug.h"
 #include <QObject>
+#include <QProcess>
 
 /**
  * \brief Abstract base class of actions to be undertaken.
@@ -165,7 +166,7 @@
        int tracks;
        int flags; } fdinfo;
 
-class K3Process;
+class KProcess;
 
 /**
  * Concrete action for running a single external program.
@@ -216,11 +217,11 @@
         /**
          * \brief Provide handling of the exit of the external program
          */
-       virtual void processDone(K3Process *);
+       virtual void processDone(int, QProcess::ExitStatus);
        /**
          * \brief Provide handling of stdout
          */
-       virtual void processStdOut(K3Process *, char *, int);
+       virtual void processStdOut(const QString &s);
        /**
          * \brief Provide handling stderr.
          *
@@ -228,18 +229,25 @@
         * to processStdOut(), so you need reimplement only
         * FloppyAction::processStdOut if you choose.
         */
-       virtual void processStdErr(K3Process *, char *, int);
+       virtual void processStdErr(const QString &s);
        
 protected:
-       K3Process *theProcess;
+       KProcess *theProcess;
        QString theProcessName;  ///< human-readable
 
        /**
         * Sets up connections, calls K3Process::run().
         * You need to *theProcess << program << args ; first.
         */
                
        bool startProcess();
+private slots:
+       /**
+        * These functions read stdout/stderr and call
+        * processStdOut()/processStdErr() accordingly
+        */
+       void readStdOut();
+       void readStdErr();
 } ;
 
 /**
@@ -270,7 +278,7 @@
        
        bool configure(bool verify);
        
-       virtual void processStdOut(K3Process *, char *,int);
+       virtual void processStdOut(const QString &s);
 
 protected:
        static QString fdformatName;    ///< path to executable.
@@ -303,7 +311,7 @@
     /**
      * \brief Provide handling of the exit of the external program
      */
-    virtual void processDone(K3Process *);
+    virtual void processDone(int exitCode, QProcess::ExitStatus exitStatus);
 protected:
     static QString m_ddName;    ///< path to executable.
 } ;
@@ -330,7 +338,7 @@
        bool configure(bool verify, bool label, const QString &l);
        
         /// Parse output
-        virtual void processStdOut(K3Process*, char* b, int l);
+        virtual void processStdOut(const QString &s);
         
 protected:
        static QString newfs_fat;
@@ -356,7 +364,7 @@
        bool configure(bool verify, bool label, const QString &l);
 
         /// Parse output
-        virtual void processStdOut(K3Process*, char* b, int l);
+        virtual void processStdOut(const QString &s);
        
 protected:
        static QString newfs;
@@ -406,7 +414,7 @@
        bool configure(bool verify, bool label, const QString &l);
         
         /// Parse output
-        virtual void processStdOut(K3Process*, char* b, int l);
+        virtual void processStdOut(const QString &s);
 protected:
        static QString newfs;
        
@@ -228,18 +229,25 @@
 
        /**
-        * Sets up connections, calls K3Process::run().
+        * Sets up connections, calls KProcess::start().
         * You need to *theProcess << program << args ; first.
         */